function x=G0(theta,data,simfunc,other,momfunc,W,beta,m)
% PURPOSE: Numerical derivative G0 (see Oh, p. 693) using step size
% epsilon=0.1
% INPUTS see objfunc_SMM; theta must be a column vector, only theta, data
% and simfunc are non-optional
% OUT = m*1 numerical gradient
% EXAMPLE:
% G0([Gaussian_theta1],
% 'simfunc_Gaussian',[1304,50,33],'momfunc_Equidep',Uresiduals2,eye(5),[])

%disp('Computing the gradient G0hat.')

if nargin<8
    m=5;
end
if nargin<7
    beta=[];
end
if nargin<6
    W=eye(m);
end
if nargin<5
    momfunc='momfunc_Equidep';
end
if nargin<4
    other=[1304,50,333];
end

y=data;

epsilon = 0.1; % step size
[mysize1, mysize2]=size(theta);
if mysize2>mysize1
    theta=theta';
end
[sizetheta,~]=size(theta);


x=zeros(m,sizetheta);
for ii=1:sizetheta
unitvec=zeros(sizetheta,1); unitvec(ii,1)=1; % ii-th unit vector
ghatplus = ghatev((theta+unitvec*epsilon),simfunc,other,momfunc,data,W);
ghatminus = ghatev((theta-unitvec*epsilon),simfunc,other,momfunc,data,W);
x(:,ii)=(ghatplus-ghatminus)/(2*epsilon);
end