function ghat = ghatev(theta,simfunc,other,momfunc,y,W)
% function obj = objfunc_SMM(theta,simfunc,other,momfunc,y,W)
%
% Function to compute the SMM objective function
%
% INPUTS:   theta, the parameter of the copula (must be of the dimenion expected by the specified copula. eg, scalar for the Gaussian.)
%           simfunc, a string containing the name of a function that generates draws from the copula of interest
%           other, a 3x1 vector containing [T,N,seed], the sample size, cross section dimension and RNG seed to use
%           momfunc, a string containing the name of a function that generates a (Mx1) vector of moments from the data
%           y, a TxN matrix of Unif(0,1) data
%           W, a MxM weight matrix used to combine the M moments
%
% OUTPUTS: out, a scalar, the SMM objective function
%
%  Dong Hwan Oh and Andrew J. Patton
%
%  22 October 2013
%
% This code was developed for the following paper:
%
% Oh, D.H. and A.J. Patton, 2013, "Simulated Method of Moments Estimation
% for Copula-Based Multivariate Models," Journal of the American
% Statistical Association, 108(502), 689-700.


ytilde = feval(simfunc,theta,other);  % simulating data from the copula model at the proposed parameter value

mhat   = feval(momfunc,y);  % the vector moments on the original data
mtilde = feval(momfunc,ytilde);  % the vector of moments on the simulated data

ghat = mhat - mtilde;  % the difference between the two vectors of moments
obj = ghat' * W * ghat;  % the SMM objective function
