function [u raw_u] = simfunc_Gaussian(theta,other)
% function [u raw_u] = simfunc_Gaussian(rho,s)
%
% Function to simulate data from the Gaussian copula
%
% INPUTS:   theta, a scalar inside (-1,1), the parameter of the Gaussian copula
%           other, a 3x1 vector containing other information = [T,N,seed]
%
% OUTPUTS:  u, a TxN matrix of the EDF-transforms of draws from the Gaussian copula (used in estimation)
%           raw_u, a TxN matrix of the original draws from the Gaussian copula
%
%  Dong Hwan Oh and Andrew J. Patton
%
%  22 October 2013
%
% This code was developed for the following paper:
%
% Oh, D.H. and A.J. Patton, 2013, "Simulated Method of Moments Estimation
% for Copula-Based Multivariate Models," Journal of the American
% Statistical Association, 108(502), 689-700.

T = other(1);
N = other(2);
seed = other(3);


Z = skewtdis_rnd2(4,-0.5,T,seed)  ; %4,-0.5

eps = zeros(T,N);
for i = 1:N
    eps(:,i) = skewtdis_rnd2(4,0,T,i*3*seed) ; %4,0
end

raw_u = theta'*Z*ones(1,N) + eps ;

u = tiedrank(raw_u)/(T+1);

